@@ -1,11 +1,12 @@
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str
 import csv
 import decimal
 import datetime
-import json
-import sys
 import zipfile
 
-from cStringIO import StringIO
+from io import BytesIO
 from django.http import HttpResponse
 from django.shortcuts import _get_queryset
 from django_stachoutils import csv_utf8
@@ -19,15 +20,14 @@ def macroman_text_response(data, filename=None, encode=True):
         response['Content-Disposition'] = 'attachment; filename="%s"' % filename
     return response
 
+
 def encode_default(d):
-    if isinstance(d, decimal.Decimal): 
+    if isinstance(d, decimal.Decimal):
         return float(str(d))
-    elif  isinstance(d, datetime.date) or isinstance(d, datetime.datetime):
+    elif isinstance(d, datetime.date) or isinstance(d, datetime.datetime):
         return d.isoformat()
     raise TypeError
 
-def json_response(data):
-    return HttpResponse(json.dumps(data, default=encode_default), content_type='application/json')
 
 def get_object_or_none(klass, *args, **kwargs):
     queryset = _get_queryset(klass)
@@ -36,22 +36,22 @@ def get_object_or_none(klass, *args, **kwargs):
     except queryset.model.DoesNotExist:
         return None
 
+
 def xml_response(data, filename=None):
     response = HttpResponse(data, content_type='application/xml')
     if filename:
         response['Content-Disposition'] = 'attachment; filename="%s"' % filename
     return response
 
+
 def zip_response(files, filename):
     response = HttpResponse(content_type='application/zip')
     response['Content-Disposition'] = 'filename=%s' % filename
 
-    buffer = StringIO()
+    buffer = BytesIO()
     zip = zipfile.ZipFile(buffer, "w", zipfile.ZIP_DEFLATED)
-    for name, f in files:
-        if sys.version_info < (2, 6):
-            name = name.encode('latin1')
-        zip.writestr(name, f)
+    for name, bytes in files:
+        zip.writestr(name, bytes)
     zip.close()
     buffer.flush()
     ret_zip = buffer.getvalue()
@@ -59,7 +59,8 @@ def zip_response(files, filename):
     response.write(ret_zip)
     return response
 
-def csv_response(rows, filename, kwargs={'delimiter' :',', 'quoting': csv.QUOTE_ALL}):
+
+def csv_response(rows, filename, kwargs={'delimiter': ',', 'quoting': csv.QUOTE_ALL}):
     response = HttpResponse(content_type='text/csv')
     response['Content-Disposition'] = 'attachment; filename="%s"' % filename
 
@@ -67,6 +68,7 @@ def csv_response(rows, filename, kwargs={'delimiter' :',', 'quoting': csv.QUOTE_
     writer.writerows(rows)
     return response
 
+
 def createAndAppendElement(document, parentNode, tagName, text=None):
     node = document.createElement(tagName)
     parentNode.appendChild(node)
